package App::ModuleUtils;

our $DATE = '2019-10-17'; # DATE
our $VERSION = '0.728'; # VERSION

1;
# ABSTRACT: Alias for App::PMUtils

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ModuleUtils - Alias for App::PMUtils

=head1 VERSION

This document describes version 0.728 of App::ModuleUtils (from Perl distribution App-PMUtils), released on 2019-10-17.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PMUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::PMUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
